@@ -26,7 +26,7 @@
 #include <sys/stat.h>
 #include <iconv.h>
 
-#if defined (_LIBICONV_H)
+#if !defined(__APPLE__) && defined (_LIBICONV_H)
  #define iconv		libiconv
  #define iconv_open	libiconv_open
  #define iconv_close	libiconv_close
@@ -391,7 +391,7 @@ if (VERBOSE_LEVEL > 7) fprintf(stdout,"%s (line %i) NS=%i nCol=%i\n", __FILE__,
 				size_t reticonv = iconv(ICONV, &inbuf, &inlen, &outbuf, &outlen);
 				iconv_close(ICONV);
 
-				if (VERBOSE_LEVEL > 7) fprintf(stdout,"%s (line %i): %i %i %i %li\n", __FILE__, __LINE__, (int)hc->SPR, (int)inlen, (int)(pos-hdr->AS.Header), reticonv );
+				if (VERBOSE_LEVEL > 7) fprintf(stdout,"%s (line %i): %i %i %i %"PRIiPTR"\n", __FILE__, __LINE__, (int)hc->SPR, (int)inlen, (int)(pos-hdr->AS.Header), reticonv );
 
 				if (reticonv == (size_t)(-1) ) {
 					perror("AXG - conversion of title failed!!!");
@@ -606,8 +606,8 @@ if (VERBOSE_LEVEL > 7) fprintf(stdout,"%s (line %i) NS=%i nCol=%i\n", __FILE__,
 		/******  parse Date and Time ********/
 		struct tm T; 
 #ifdef __GLIBC__
-		strptime(strstr(Notes,"Created on ")+11, "%a %b %d %Y", &T); ;
-		strptime(strstr(Notes,"acquisition at ")+15, "%T", &T); ;
+		strptime(strstr(Notes,"Created on ")+11, "%a %b %d %Y", &T);
+		strptime(strstr(Notes,"acquisition at ")+15, "%T", &T);
 		hdr->T0 = tm_time2gdf_time(&T);
 #else
 		char DATE[30];
